<?php

namespace Drupal\smallads_murmurations;

use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides local actions to create smallads of each type.
 */
class NetworkSearchMenuTasks extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  protected $storage = [];

  /**
   * {@inheritdoc}
   */
  public function __construct($smallad_type_storage) {
    $this->storage = $smallad_type_storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity_type.manager')->getStorage('smallad_type')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    foreach (['offer', 'want'] as $smallad_type_id) {
      $type = $this->storage->load($smallad_type_id);
      // Route names generated at smallads_smallad_type_insert
      $this->derivatives["{$smallad_type_id}_global"] = [
        'title' => $this->t("Global", ['@smalladtypes' => $type->labelPlural()]),
        'description' => $this->t('Search ads accross the network'),
        'base_route' => 'view.smallads_auto_page.'. $smallad_type_id,
        'route_name' => $route_name ?? 'smallads_murmurations.search.'. $smallad_type_id,
        'weight' => 2,
        'id' => "{$smallad_type_id}_global"
      ] + $base_plugin_definition;
    }
    return $this->derivatives;
  }

}
