<?php

namespace Drupal\smallads_murmurations;

use Drupal\Core\Form\FormStateInterface;

class OffersWantsFilterForm extends \Drupal\murmurations\Form\FilterForm {

  protected $aggregator_url;

  public function __construct($user_data, $request) {
    parent::__construct($user_data, $request);
    $this->aggregator_url = $this->config('murmurations.settings')->get('aggregators.offer_want');
  }

  /**
   * {@inheritDoc}
   */
  function buildForm(array $form, FormStateInterface $form_state) {
    $tags = explode(',', $_GET['tags']??'');
    $item_type = in_array('service', $tags) ? 'service' : 'good';
    $exchange_type = in_array('want', $tags) ? 'want' : 'offer';
    unset(
      $tags[array_search('good', $tags)],
      $tags[array_search('service', $tags)],
      $tags[array_search('offer', $tags)],
      $tags[array_search('want', $tags)],
    );
    $_GET['tags'] = implode(',', $tags);
    if ($this->aggregator_url) {
      $prefs = $this->userData
       ->get('murmurations', $this->currentUser()->id(), 'pref');

      $form['#attached']['library'][] = 'smallads_murmurations/filter_form'; //flatten radio buttons

      $form['item_type'] = [
        '#title' => '',
        '#type' => 'radios',
        '#options' => [
          'good' => $this->t('Good'),
          'service' => $this->t('Service'),
        ],
        '#default_value' => $item_type,
        '#weight' => 5
      ];
      $form['exchange_type'] = [
        '#title' => '',
        '#type' => 'radios',
        '#options' => [
          'offer' => $this->t('Offer'),
          'want' => $this->t('Request'),
        ],
        '#default_value' => $exchange_type,
        '#weight' => 5
      ];
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritDoc}
   */
  function submitForm(array &$form, FormStateInterface $form_state) {
    if (!$this->aggregator_url) {
      return parent::submitForm($form, $form_state);
    }
    //save the search settings
    $prefs = [
      'range' => $form_state->getValue('range'), // 'km' added in parent
      'free' => $form_state->getValue('free'),
      'service' => $form_state->getValue('service'),
      'money' => $form_state->getValue('money')
    ];
    // remember the user settings.
    $this->userData
     ->set('murmurations', $this->currentUser()->id(), 'pref', $prefs);

    $tags = explode(',', trim($form_state->getValue('tags')));
    $tags[] = $form_state->getvalue('item_type');
    $tags[] = $form_state->getvalue('exchange_type');
    $tags = array_unique(array_filter($tags));

    $form_state->setRedirect(
      \Drupal::routeMatch()->getRouteName(),// @todo inject this
      [],
      [
        'query' => [
          'tags' => implode(',',$tags),
        ] + array_filter($prefs)
      ]
    );
  }

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'smallads_murmurations_filter_form';
  }

  /**
   * Construct the query string, send, and return the result items
   * @return array
   * @todo
   */
  protected function __getResults(array $params) : array {
//    if ($query->has('free')) {
//      $filters['free'] = 1;
//    }
//    if ($query->has('service')) {
//      if ($query->get('service') == 0) {
//        $filters['service'] = 0;
//      }
//    }
    return parent::getResults($params);
  }


  /**
   * Submit to the search engine and parse the results a bit
   * Add the offers and wants filters to the search being done by the parent.
   */
  protected function searchRequest(array $params, string $aggregator_url = NULL) {

    // Generic search filters
    $params['schema'] = \Drupal::service('plugin.manager.murmurations')->getDefinition('offer_want')['schema'];
    // for now we're sending it all the index, so use the parent function

    return parent::searchRequest($params, $aggregator_url);
  }

}
