<?php

namespace Drupal\smallads_murmurations\Plugin\Murmurations;

use Drupal\smallads\Entity\SmalladInterface;
use Drupal\murmurations\MurmurationsPluginMultipleBase;

/**
 * Share's the site data as murmurations Organisation schema
 *
 * @Murmurations(
 *   id = "offer_want",
 *   label = @Translation("Offer/Want"),
 *   schema = "offers_wants_prototype-v0.0.2",
 *   publish_path = "ad/{smallad}/murmurations.json",
 *   entity_type = "smallad"
 * )
 */
class OfferWant extends MurmurationsPluginMultipleBase {

  protected $entity;

  function getProfile() : array {
    $smallad = $this->entity;
    //'buy-sell',"borrow-lend", "rent-lease", "receive-donate"
    $t_types = [];
    if ($smallad->money->value) {
      $t_types[] = 'buy-sell';
    }
    if ($smallad->free->value) {
      $t_types[] = 'receive-donate';
    }
    if ($smallad->service->value) {
      $t_types[] = $smallad->money->value ? 'rent-lease' : 'borrow-lend';
    }
    if (empty($t_types)) {
      $t_types[] = 'buy-sell';
    }
    $tags = array_map(
      function ($term) {return $term->label();},
      $smallad->categories->referencedEntities()
    );
    // Temp until the aggregator is built
    $tags[] = $smallad->bundle();
    $tags[] = $smallad->service->value ? 'service' : 'good';

    $output = parent::getProfile() + [
      'title' => $smallad->label(),
      'description' => $smallad->body->value,
      'exchange_type' => $smallad->bundle(),
      'item_type' => $smallad->service->value ? 'service' : 'good',
      'transaction_type' => $t_types,
      'details_url' => $smallad->toUrl()->setAbsolute()->toString(),
      'geographic_scope' => 'local',
      'expires_at' => strtotime($smallad->expires->value),
      'tags' => $tags,
      'contact_details' => [
        'contact_form' => \Drupal::urlGenerator()->generateFromRoute('entity.user.contact_form', ['user' => $smallad->getOwnerId()], ['absolute' => TRUE]),
      ]
    ];
    if ($smallad->image) {
      $output['image'] = $smallad->image->entity->createFileUrl(FALSE);
    }
    return $output;
  }

  /**
   * {@inheritDoc}
   */
  function needed() : string {
    return smallads_user_has_geofield() ? '' : t('The user entity must have a geofield.');
  }

  /**
   * Get the ids of the entities to share.
   *
   * @return array
   */
  function getEntityIds() : array {
    return \Drupal::entityQuery('smallad')
      ->condition('scope', SmalladInterface::SCOPE_NETWORK, '>=')
      ->condition('type', ['offer', 'want'], 'IN')
      ->execute();
  }

  /**
   * {@inheritDoc}
   */
  function publishable($smallad) : bool {
    return $smallad->scope->value >= SmalladInterface::SCOPE_NETWORK;
  }

}
